% function y = newtonev(xd,d,x)
%
% uses Horner's algorithm to evaluate the Newton interpolation polynomial
% at the points x, where the interpolation nodes are given in xd
%
% Inputs
%   xd  interpolation nodes
%   d   coefficients of the Newton interpolation polynomial
%   x   points of evaluation of the Newton interpolation polynomial
%
% Outputs
%   y   p(x)
%
function y = newtonev(xd,d,x)
% sanity check
if (length(d)~=length(xd)) 
 error('there must be as many divided differences as interpolation nodes');
end;

% TO BE COMPLETED
